"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require("../");
const hub_1 = require("./hub");
class HubBuilder {
    constructor() {
        this.supportedServers = [];
    }
    static get instance() {
        return this._instance || (this._instance = new HubBuilder());
    }
    withContainer(container) {
        this.container = container;
        return this;
    }
    withFramework(tsFramework) {
        this.tsFramework = tsFramework;
        return this;
    }
    withServerSupport(server, serverConfigurator) {
        this.supportedServers.push({ server: server, serverConfigurator: serverConfigurator });
        return this;
    }
    buildHub() {
        this.initializeContainer()
            .initializeFramework();
        var controllerLoader = this.tsFramework.setupFramework();
        return new hub_1.Hub(this.supportedServers, this.container, controllerLoader);
    }
    initializeFramework() {
        if (!this.tsFramework) {
            throw "No framework was configured";
        }
        return this;
    }
    initializeContainer() {
        this.container = this.container || new _1.InversifyContainer();
        this.container.bind(_1.Types.Container).toConstantValue(this.container);
        return this;
    }
}
exports.HubBuilder = HubBuilder;
//# sourceMappingURL=hub-builder.js.map