"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class Hub {
    constructor(serverConfigs, container, controllerLoader) {
        this.serverConfigs = serverConfigs;
        this.container = container;
        this.controllerLoader = controllerLoader;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            var controllerBuilders = this.controllerLoader.loadControllerBuilders(this.container);
            var promises = this.serverConfigs.map((serverConfig) => {
                serverConfig.serverConfigurator && serverConfig.serverConfigurator.configureServer(serverConfig.server, this.container);
                controllerBuilders = controllerBuilders.filter((controllerBuilder) => {
                    if (controllerBuilder.supportsServer(serverConfig.server)) {
                        var controller = controllerBuilder.buildController();
                        controller.attachToServer(serverConfig.server);
                        return false;
                    }
                    return true;
                });
                return serverConfig.server.run();
            });
            return Promise.all(promises);
        });
    }
    stop() {
        var promises = this.serverConfigs.map((serverConfig) => {
            if (serverConfig.server) {
                return Promise.resolve(true);
            }
            return serverConfig.server.stop();
        });
        return Promise.all(promises);
    }
}
exports.Hub = Hub;
//# sourceMappingURL=hub.js.map